<?php $TRANSLATIONS = array(
"OpenID Changed" => "OpenID schimbat",
"Invalid request" => "Cerere eronată",
"This is an OpenID server endpoint. For more information, see " => "Acesta este un server final OpenID. Pentru mai multe informații, vezi ",
"Identity: <b>" => "Identitate: <b>",
"Realm: <b>" => "Tiparul: <b>",
"User: <b>" => "Utilizator: <b>",
"Login" => "Autentificare",
"Error: <b>No user Selected" => "Eroare:: <b>Nici un utilizator selectat",
"OpenID" => "OpenID",
"you can authenticate to other sites with this address" => "nu te poți autentifica în alte site-uri cu această adresă",
"Authorized OpenID provider" => "Ofertant autorizat OpenID",
"Your address at Wordpress, Identi.ca, &hellip;" => "Adresa ta la Wordpress, Identi.ca &hellip;"
);
